v1.0.3
=======
- auto re-login functionality expanded to service accounts
- fix to docstrings display bug
- fix to the username that is set up for service accounts
- creation_mode field added to the DataFrame that is a product of the following functions:
    * :func:`rohub.list_my_ros`
    * :func:`rohub.ros_find`
- added functions
    * :func:`ResearchObject.delete_folder`
- folder can now be referenced with full path instead of internal identifier
- python property "folder" for the Resource object will show folder's full path instead of internal identifier
- catching a situation where there is no valid research_area for the ro before sending a request and prompting user about the issue
- :func:`rohub.resource_update_metadata` and :func:`Resource.update_metadata` are now having optional argument ro_id, which should be provided along with folder